# Banking Contacts
A list of banking contacts for the selected person/company saved in the database. Banking contacts will also include data from a person's primary employer. If the person has no primary employer it will include banking details from every one of its employers.

## Columns:
Each column title has three lines on the right if you hover over it. Click on them to show options for that column. The second tab of the options menu will allow you to filter the column, the third to completely hide entire columns. Click on anywhere else on the column to order it, cycling between ascending, descending and no ordering. Hold shift while clicking to order multiple columns with individual weights.

### Location:
The contact's location of use. Can be one of four locations: Work, Private, Home or Other. Work will be selected by default when creating a new contact.

### Institute:
The name of the banking contact's institute.

### Institute additional:
Additional information about the institute, e.g. address.

### IBAN:
International Bank Account Number of the banking contact.

### SWIFT:
The contact's SWIFT code/BIC.

### Currency:
The bank's currency.

### Edited:
Date and time of last edit to the contact.

### Information:
Displays additional information that can be used instead of the IBAN to communicate banking details.

## Primary Functionality:
Primary banking contacts cannot be deleted unless they are the entry's last banking contact. You need to make one of the other contacts their primary banking contact before being able to delete that contact.

## Legend:
Click on the legend to filter primary banking contacts. When displaying banking contacts of a person you can also filter contacts belonging to the person's employer(s) by clicking on the legend "Company Contact".

## Search Field:
Typing in the search field allows to filter the banking contacts by their institute, IBAN and SWIFT.
